==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "VST 3 SDK", "index.html", [
    [ "Introduction", "index.html", [
      [ "Welcome to VST SDK 3.7", "index.html#vst3sdkIntro", null ],
      [ "About VST Plug-ins in general", "index.html#vstPlugGeneral", null ],
      [ "About VST 3", "index.html#vst3General", null ]
    ] ],
    [ "to use the validator to run your own tests?", "How.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"AudioIO_8h.html",
"classSteinberg_1_1Vst_1_1BypassProcessor.html#add33a3d56ac667b24bdf9a292a5bd36c",
"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a9bf9df82b8772ce781fb2860e204a8df",
"classSteinberg_1_1Vst_1_1PluginContextFactory.html#a2400af6b76b72f7cfb23172352124110",
"classSteinberg_1_1Vst_1_1StringListParameter.html#ab8cb2d05d8f8af76a610e783faecb324",
"classVST3_1_1Hosting_1_1Module.html#ae9087247e1a6e9b3d267c9546b4f8762",
"mpeprocessor_8h.html#ab4311216475ec4d94c471bb87ed1721e",
"namespaceSteinberg.html#ada58d6deb48a2fa3d115398537b0fa93",
"namespaceSteinberg_1_1Vst.html#ad0e23cf02b8fa84dad11b10435b6e82c",
"namespaceSteinberg_1_1Vst_1_1MusicalInstrument.html#a58fd32018d0d25fa22a065fe293e4079",
"namespaceSteinberg_1_1Vst_1_1SpeakerArr.html#a153beb2d5d562ed4fc8643bf51c711d8",
"namespaceSteinberg_1_1Vst_1_1SpeakerArr.html#ac5315e218c209f891d18ec25effa0fd1",
"structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a527d5a9fd900143afb37fd62da983285",
"structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageChannelVoice1.html#a67a0db04d321a74b7e7fcfd3f1a3f70b",
"structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#ac25995a2224432b3e6b86214f7740973aa0bfb8e59e6c13fc8d990781f77694fe",
"structVST3_1_1Vst2xState.html#a8aa5d2f3cc07a2001fe735b8dca8e945",
""
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "VST 3 SDK", "index.html", [
    [ "Introduction", "index.html", "index" ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"AudioIO_8h.html",
"classSteinberg_1_1Vst_1_1BypassProcessor.html#af03bc4cf393d19019897417293c55663",
"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#ab37e7ad7503043f64fb3e36cada470eb",
"classSteinberg_1_1Vst_1_1PresetFile.html#a9e8e502499657ad0cb2d1ca286fd906c",
"classSteinberg_1_1Vst_1_1ThreadChecker.html#a6c5ade0a1125312d44f7c331e20d69d9",
"functions_m.html",
"group__musicalStyle.html#ga60c65b0575b241924ccfcc59fa7dccaf",
"group__speakerArrangements.html#ga5756399f47d692e0e5e587bcc8a06a9d",
"group__speakerArrangements.html#gaf19e8a3b3f0d3a2c0e9587f6cc9b1411",
"namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf6db7ad5110a115d774dd8d74d333a42",
"namespaceSteinberg_1_1Vst.html#a7d66c573aff27d890ec154f45b61f310a1c30475ef992f89f37c2fe0aafcc6283",
"namespaceSteinberg_1_1Vst_1_1UMP_1_1Detail.html#a1bc3ccf4d567ca83c993c3aaa8124904aeb7a9ac9f662bc5dc17e8d1f12cf2e17",
"structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#aa7c29f403466f1932768cd801b98ed79",
"structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#a07859aa4165b1d16bc6580571a0fb8ca",
"structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a7945fc22e5d1821e4e22fbf8a9722339"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
